==> kyt-1.2.5.tgz: package/lib/config/StartServerPlugin.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var cluster = require('cluster');
/* eslint-disable class-methods-use-this,no-underscore-dangle */


var StartServerPlugin = /*#__PURE__*/function () {
  function StartServerPlugin(options) {
    (0, _classCallCheck2["default"])(this, StartServerPlugin);

    if (options == null) {
      options = {};
    }

    if (typeof options === 'string') {
      options = {
        name: options
      };
    }

    this.options = _objectSpread({
      signal: false,
      // Only listen on keyboard in development, so the server doesn't hang forever
      keyboard: process.env.NODE_ENV === 'development'
    }, options);
    this.afterEmit = this.afterEmit.bind(this);
    this.apply = this.apply.bind(this);
    this.startServer = this.startServer.bind(this);
    this.worker = null;

    if (this.options.restartable !== false) {
      this._enableRestarting();
    }
  }

  (0, _createClass2["default"])(StartServerPlugin, [{
    key: "_enableRestarting",
    value: function _enableRestarting() {
      var _this = this;

      if (this.options.keyboard) {
        process.stdin.setEncoding('utf8');
        process.stdin.on('data', function (data) {
          if (data.trim() === 'rs') {
            console.log('Restarting app...');
            process.kill(_this.worker.process.pid);
            cluster.fork();
          }
        });
      }
    }
  }, {
    key: "_getExecArgv",
    value: function _getExecArgv() {
      var options = this.options;
      var execArgv = (options.nodeArgs || []).concat(process.execArgv); // eslint-disable-next-line kyt/no-immediate-return

      return execArgv;
    }
  }, {
    key: "_getArgs",
    value: function _getArgs() {
      var options = this.options;
      var argv = options.args || []; // eslint-disable-next-line kyt/no-immediate-return

      return argv;
    }
  }, {
    key: "_getInspectPort",
    value: function _getInspectPort(execArgv) {
      var inspectArg = execArgv.find(function (arg) {
        return arg.includes('--inspect');
      });

      if (!inspectArg || !inspectArg.includes('=')) {
        return null;
      }

      var hostPort = inspectArg.split('=')[1];
      var port = hostPort.includes(':') ? hostPort.split(':')[1] : hostPort;
      return parseInt(port, 10);
    }
  }, {
    key: "_getSignal",
    value: function _getSignal() {
      var signal = this.options.signal; // allow users to disable sending a signal by setting to `false`...

      if (signal === false) return null;
      if (signal === true) return 'SIGUSR2';
      return signal;
    }
  }, {
    key: "afterEmit",
    value: function afterEmit(compilation, callback) {
      if (this.worker && this.worker.isConnected()) {
        var signal = this._getSignal();

        process.kill(this.worker.process.pid, signal);
        cluster.fork();
        return;
      }

      this.startServer(compilation, callback);
    }
  }, {
    key: "apply",
    value: function apply(compiler) {
      // Use the Webpack 4 Hooks API when possible.
      if (compiler.hooks) {
        var plugin = {
          name: 'StartServerPlugin'
        };
        compiler.hooks.afterEmit.tapAsync(plugin, this.afterEmit);
      } else {
        compiler.plugin('after-emit', this.afterEmit);
      }
    }
  }, {
    key: "startServer",
    value: function startServer(compilation, callback) {
      var _this2 = this;

      var options = this.options;
      var name;
      var names = Object.keys(compilation.assets);

      if (options.name) {
        name = options.name;

        if (!compilation.assets[name]) {
          console.error("Entry ".concat(name, " not found. Try one of: ").concat(names.join(' ')));
        }
      } else {
        var _names = (0, _slicedToArray2["default"])(names, 1);

        name = _names[0];

        if (names.length > 1) {
          console.log("More than one entry built, selected ".concat(name, ". All names: ").concat(names.join(' ')));
        }
      }

      var existsAt = compilation.assets[name].existsAt;
      this._entryPoint = existsAt;

      this._startServer(function (worker) {
        _this2.worker = worker;
        callback();
      });
    }
  }, {
    key: "_startServer",
    value: function _startServer(callback) {
      var args = this._getArgs();

      var execArgv = this._getExecArgv();

      var inspectPort = this._getInspectPort(execArgv);

      var clusterOptions = {
        exec: this._entryPoint,
        execArgv: execArgv,
        args: args
      };

      if (inspectPort) {
        clusterOptions.inspectPort = inspectPort;
      }

      cluster.setupMaster(clusterOptions);
      cluster.on('online', function (worker) {
        callback(worker);
      });
      cluster.fork();
    }
  }]);
  return StartServerPlugin;
}();

module.exports = StartServerPlugin;

==> kyt-1.2.9.tgz: package/lib/config/StartServerPlugin.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));
var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
var cluster = require('cluster');

/* eslint-disable class-methods-use-this,no-underscore-dangle */
var StartServerPlugin = /*#__PURE__*/function () {
  function StartServerPlugin(options) {
    (0, _classCallCheck2["default"])(this, StartServerPlugin);
    if (options == null) {
      options = {};
    }
    if (typeof options === 'string') {
      options = {
        name: options
      };
    }
    this.options = _objectSpread({
      signal: false,
      // Only listen on keyboard in development, so the server doesn't hang forever
      keyboard: process.env.NODE_ENV === 'development'
    }, options);
    this.afterEmit = this.afterEmit.bind(this);
    this.apply = this.apply.bind(this);
    this.startServer = this.startServer.bind(this);
    this.worker = null;
    if (this.options.restartable !== false) {
      this._enableRestarting();
    }
  }
  (0, _createClass2["default"])(StartServerPlugin, [{
    key: "_enableRestarting",
    value: function _enableRestarting() {
      var _this = this;
      if (this.options.keyboard) {
        process.stdin.setEncoding('utf8');
        process.stdin.on('data', function (data) {
          if (data.trim() === 'rs') {
            console.log('Restarting app...');
            process.kill(_this.worker.process.pid);
            cluster.fork();
          }
        });
      }
    }
  }, {
    key: "_getExecArgv",
    value: function _getExecArgv() {
      var options = this.options;
      var execArgv = (options.nodeArgs || []).concat(process.execArgv);
      // eslint-disable-next-line kyt/no-immediate-return
      return execArgv;
    }
  }, {
    key: "_getArgs",
    value: function _getArgs() {
      var options = this.options;
      var argv = options.args || [];
      // eslint-disable-next-line kyt/no-immediate-return
      return argv;
    }
  }, {
    key: "_getInspectPort",
    value: function _getInspectPort(execArgv) {
      var inspectArg = execArgv.find(function (arg) {
        return arg.includes('--inspect');
      });
      if (!inspectArg || !inspectArg.includes('=')) {
        return null;
      }
      var hostPort = inspectArg.split('=')[1];
      var port = hostPort.includes(':') ? hostPort.split(':')[1] : hostPort;
      return parseInt(port, 10);
    }
  }, {
    key: "_getSignal",
    value: function _getSignal() {
      var signal = this.options.signal;
      // allow users to disable sending a signal by setting to `false`...
      if (signal === false) return null;
      if (signal === true) return 'SIGUSR2';
      return signal;
    }
  }, {
    key: "afterEmit",
    value: function afterEmit(compilation, callback) {
      if (this.worker && this.worker.isConnected()) {
        var signal = this._getSignal();
        process.kill(this.worker.process.pid, signal);
        cluster.fork();
        return;
      }
      this.startServer(compilation, callback);
    }
  }, {
    key: "apply",
    value: function apply(compiler) {
      // Use the Webpack 4 Hooks API when possible.
      if (compiler.hooks) {
        var plugin = {
          name: 'StartServerPlugin'
        };
        compiler.hooks.afterEmit.tapAsync(plugin, this.afterEmit);
      } else {
        compiler.plugin('after-emit', this.afterEmit);
      }
    }
  }, {
    key: "startServer",
    value: function startServer(compilation, callback) {
      var _this2 = this;
      var options = this.options;
      var name;
      var names = Object.keys(compilation.assets);
      if (options.name) {
        name = options.name;
        if (!compilation.assets[name]) {
          console.error("Entry ".concat(name, " not found. Try one of: ").concat(names.join(' ')));
        }
      } else {
        name = names[0];
        if (names.length > 1) {
          console.log("More than one entry built, selected ".concat(name, ". All names: ").concat(names.join(' ')));
        }
      }
      var existsAt = compilation.assets[name].existsAt;
      this._entryPoint = existsAt;
      this._startServer(function (worker) {
        _this2.worker = worker;
        callback();
      });
    }
  }, {
    key: "_startServer",
    value: function _startServer(callback) {
      var args = this._getArgs();
      var execArgv = this._getExecArgv();
      var inspectPort = this._getInspectPort(execArgv);
      var clusterOptions = {
        exec: this._entryPoint,
        execArgv: execArgv,
        args: args
      };
      if (inspectPort) {
        clusterOptions.inspectPort = inspectPort;
      }
      cluster.setupMaster(clusterOptions);
      cluster.on('online', function (worker) {
        callback(worker);
      });
      cluster.fork();
    }
  }]);
  return StartServerPlugin;
}();
module.exports = StartServerPlugin;
